# modified from the python library faker:
# https://github.com/joke2k/faker/blob/master/faker/providers/person/hr_HR/__init__.py

person_formats_hr_hr <- "{{first_names}} {{last_names}}"

person_first_names_male_hr_hr <- c(
  "Aldo",
  "Alen",
  "Andrija",
  "Ante",
  "Anto",
  "Anton",
  "Antonio",
  "Antun",
  "Boris",
  "Bo\u017eo",
  "Branko",
  "Bruno",
  "Dalibor",
  "Damir",
  "Danijel",
  "Dario",
  "Darko",
  "David",
  "Davor",
  "Dejan",
  "Denis",
  "Dino",
  "Domagoj",
  "Dominik",
  "Dragan",
  "Dragutin",
  "Dra\u017een",
  "Duje",
  "Du\u0161an",
  "Elvis",
  "Erik",
  "Filip",
  "Fran",
  "Franjo",
  "Goran",
  "Hrvoje",
  "Igor",
  "Ilija",
  "Ivan",
  "Ivica",
  "Ivo",
  "Jakov",
  "Janko",
  "Josip",
  "Joso",
  "Jozo",
  "Jo\u0161ko",
  "Juraj",
  "Jure",
  "Karlo",
  "Kristijan",
  "Leon",
  "Lovre",
  "Lovro",
  "Luka",
  "Marijan",
  "Marin",
  "Mario",
  "Marko",
  "Martin",
  "Mate",
  "Matej",
  "Mateo",
  "Matija",
  "Mato",
  "Mihael",
  "Mijo",
  "Milan",
  "Mile",
  "Mirko",
  "Miroslav",
  "Mislav",
  "Mladen",
  "Nenad",
  "Niko",
  "Nikola",
  "Nik\u0161a",
  "Patrik",
  "Pavao",
  "Pero",
  "Petar",
  "Robert",
  "Roko",
  "Romano",
  "Rudolf",
  "Sa\u0161a",
  "Sini\u0161a",
  "Slavko",
  "Stjepan",
  "Tomislav",
  "Tomo",
  "Toni",
  "Valter",
  "Vedran",
  "Viktor",
  "Vjekoslav",
  "Vladimir",
  "Vlado",
  "Zdravko",
  "Zlatko",
  "Zoran",
  "Zvonko",
  "\u0110uro",
  "\u0160ime",
  "\u017deljko"
)

person_first_names_female_hr_hr <- c(
  "Albina",
  "Ana",
  "Andrea",
  "Ane",
  "Anica",
  "Anita",
  "Anka",
  "Ankica",
  "Antonija",
  "An\u0111a",
  "An\u0111ela",
  "Bara",
  "Barbara",
  "Barica",
  "Biljana",
  "Biserka",
  "Bo\u017eena",
  "Bo\u017eica",
  "Branka",
  "Danica",
  "Danijela",
  "Dora",
  "Draga",
  "Dragica",
  "Elizabeta",
  "Ema",
  "Eva",
  "Franciska",
  "Fuma",
  "Gordana",
  "Hana",
  "Ika",
  "Iva",
  "Ivana",
  "Ivanka",
  "Ivka",
  "Jadranka",
  "Jana",
  "Janja",
  "Jasminka",
  "Jasna",
  "Jele",
  "Jelena",
  "Josipa",
  "Julijana",
  "Karla",
  "Kata",
  "Katarina",
  "Kate",
  "Katica",
  "Kristina",
  "Lana",
  "Lara",
  "Laura",
  "Lea",
  "Lidija",
  "Ljiljana",
  "Ljubica",
  "Lorena",
  "Lucija",
  "Maja",
  "Manda",
  "Mara",
  "Mare",
  "Maria",
  "Marica",
  "Marija",
  "Marijana",
  "Marina",
  "Marta",
  "Martina",
  "Matea",
  "Mateja",
  "Matija",
  "Mia",
  "Milena",
  "Milica",
  "Milka",
  "Mira",
  "Mirjana",
  "Nada",
  "Nata\u0161a",
  "Nevenka",
  "Nika",
  "Nikolina",
  "Nina",
  "Petra",
  "Renata",
  "Rozalija",
  "Ru\u017ea",
  "Ru\u017eica",
  "Sandra",
  "Sanja",
  "Sara",
  "Slavica",
  "Snje\u017eana",
  "Stana",
  "Suzana",
  "Tatjana",
  "Tea",
  "Terezija",
  "Valentina",
  "Vera",
  "Veronika",
  "Vesna",
  "Zdenka",
  "Zora",
  "Zorka",
  "\u0110ur\u0111ica",
  "\u0160tefanija",
  "\u0160tefica",
  "\u017deljka"
)

person_first_names_hr_hr <- c(person_first_names_female_hr_hr, person_first_names_male_hr_hr)
person_last_names_hr_hr <- c(
  "Abi\u010di\u0107",
  "Abramovi\u0107",
  "Ad\u017eijevi\u0107",
  "Akma\u010di\u0107",
  "Alkovi\u0107",
  "Amanovi\u0107",
  "Amid\u017ei\u0107",
  "Andra\u0161ek",
  "Andrija\u0161evi\u0107",
  "Andrijevi\u0107",
  "Ani\u010di\u0107",
  "Anti\u0107",
  "Antolkovi\u0107",
  "Antoni\u0107",
  "Babi\u0107",
  "Bajan",
  "Baksa",
  "Balatinac",
  "Balin\u010di\u0107",
  "Bali\u0107",
  "Baljak",
  "Ban",
  "Bani\u010devi\u0107",
  "Banko",
  "Banovac",
  "Barac",
  "Bara\u0107",
  "Barbieri",
  "Barbir",
  "Barbi\u0107",
  "Bare\u0161i\u0107",
  "Bari\u0107",
  "Bari\u010devi\u0107",
  "Bari\u0161i\u0107",
  "Barkovi\u0107",
  "Barnaba",
  "Baru\u0161i\u0107",
  "Batrac",
  "Batrnek",
  "Bazjak",
  "Ba\u010dak",
  "Ba\u010di\u0107",
  "Ba\u0161i\u0107",
  "Ba\u0161nec",
  "Bebi\u0107",
  "Begonja",
  "Beleti\u0107",
  "Belo\u0161evi\u0107",
  "Beni\u0107",
  "Ben\u010di\u0107",
  "Berakovi\u0107",
  "Bernardi\u0107",
  "Berto\u0161a",
  "Bezi\u0107",
  "Bijeli\u0107",
  "Bingula",
  "Birki\u0107",
  "Birti\u0107",
  "Bi\u0107ani\u0107",
  "Bi\u010dak",
  "Bi\u010dani\u0107",
  "Bjeli\u0161",
  "Blagai\u0107",
  "Bla\u017eek",
  "Bla\u017eevi\u0107",
  "Bla\u017ei\u010dko",
  "Boban",
  "Bobanovi\u0107",
  "Bogadi",
  "Bogdan",
  "Bogovi\u0107",
  "Bojani\u0107",
  "Boljkovac",
  "Bol\u010devi\u0107",
  "Borak",
  "Borojevi\u0107",
  "Boro\u0161ak",
  "Bosilj",
  "Botica",
  "Boti\u0107",
  "Bo\u0161njak",
  "Bo\u0161njakovi\u0107",
  "Bo\u017eani\u0107",
  "Bo\u017eanovi\u0107",
  "Bo\u017eikovi\u0107",
  "Bo\u017ei\u0107",
  "Bo\u017ei\u010devi\u0107",
  "Bo\u017ei\u010dkovi\u0107",
  "Bradi\u0107",
  "Brajkovi\u0107",
  "Brali\u0107",
  "Brandi\u0107",
  "Brankovi\u0107",
  "Bra\u010dun",
  "Brcko",
  "Brezjan",
  "Britvec",
  "Brlas",
  "Brlek",
  "Brleti\u0107",
  "Bukvi\u0107",
  "Buljan",
  "Bungi\u0107",
  "Buni\u0107",
  "Bun\u010di\u0107",
  "Buri\u0107",
  "Bur\u010dul",
  "Bur\u0161i\u0107",
  "Butkovi\u0107",
  "Buzov",
  "Bu\u010danac",
  "Bu\u010dar",
  "Bu\u0161ljeta",
  "Cafuk",
  "Car",
  "Cari\u0107",
  "Cestari\u0107",
  "Ciganovi\u0107",
  "Cik",
  "Cindri\u0107",
  "Coli\u0107",
  "Crevar",
  "Crnekovi\u0107",
  "Crnkovi\u0107",
  "Cukon",
  "Culi",
  "Cveni\u0107",
  "Cvetkovi\u0107",
  "Cvetni\u0107",
  "Cvitan",
  "Cvrtila",
  "Dabo",
  "Damijani\u0107",
  "Damjanovi\u0107",
  "Darojkovi\u0107",
  "Dautanec",
  "Dautovi\u0107",
  "Debeli\u0107",
  "Dere\u017ei\u0107",
  "De\u017ee",
  "Didovi\u0107",
  "Dizdar",
  "Dobri\u0107",
  "Dolinar",
  "Doli\u0107",
  "Dominikovi\u0107",
  "Dominkovi\u0107",
  "Don\u010devi\u0107",
  "Dragi\u010devi\u0107",
  "Dragobratovi\u0107",
  "Dragojevi\u0107",
  "Drakuli\u0107",
  "Drandi\u0107",
  "Dra\u017ei\u0107",
  "Dretvi\u0107",
  "Dubove\u010dak",
  "Dujmovi\u0107",
  "Duki\u0107",
  "Duvan\u010di\u0107",
  "Dvojak",
  "D\u017eapo",
  "Erceg",
  "Ercegovi\u0107",
  "Ergoti\u0107",
  "Er\u0161ek",
  "Eterovi\u0107",
  "Fabijani\u0107",
  "Ferenac",
  "Filar",
  "Filipovi\u0107",
  "Filip\u010di\u0107",
  "Flego",
  "Forjan",
  "Frani\u0107",
  "Frani\u010devi\u0107",
  "Franji\u0107",
  "Franu\u0161i\u0107",
  "Fri\u0161\u010di\u0107",
  "Frketi\u0107",
  "Fu\u010dek",
  "Gabud",
  "Gale\u0161i\u0107",
  "Gali\u0107",
  "Galovi\u0107",
  "Gegi\u0107",
  "Gelemanovi\u0107",
  "Glasnovi\u0107",
  "Glavan",
  "Glavor",
  "Gligora",
  "Godini\u0107",
  "Golubi\u0107",
  "Goti\u0107",
  "Govor\u010dinovi\u0107",
  "Gracin",
  "Grba",
  "Grbac",
  "Gredi\u010dak",
  "Gregov",
  "Grgi\u0107",
  "Grgurevi\u0107",
  "Grguri\u0107",
  "Grgurovac",
  "Grubi\u0161i\u0107",
  "Gr\u017eeti\u0107",
  "Gr\u017ein\u010di\u0107",
  "Guberovi\u0107",
  "Gudelj",
  "Gulan",
  "Gu\u0161tin",
  "Hadrovi\u0107",
  "Had\u017ei\u0107",
  "Halambek",
  "Halapir",
  "Han\u017eek",
  "Harapin",
  "Hardi",
  "Herceg",
  "Herout",
  "He\u0107imovi\u0107",
  "Hini\u0107",
  "Hodak",
  "Horak",
  "Horvat",
  "Horvatek",
  "Horvatinec",
  "Horvati\u0107",
  "Hrabar",
  "Hrani\u0107",
  "Hranj",
  "Hrastinski",
  "Hren",
  "Hrvoji\u0107",
  "Hr\u0161ak",
  "Hr\u017eenjak",
  "Huljev",
  "Husnjak",
  "Ignac",
  "Iliji\u0107",
  "Ilinovi\u0107",
  "Ili\u0107",
  "Ivandi\u0107",
  "Ivanovi\u0107",
  "Ivan\u010dan",
  "Iv\u0161i\u0107",
  "Jagarinec",
  "Jage\u010di\u0107",
  "Jakopec",
  "Jakopovi\u0107",
  "Jakovac",
  "Jakovi\u0107",
  "Jakovljevi\u0107",
  "Jakupi\u0107",
  "Jaku\u0161",
  "Jasprica",
  "Jelavi\u0107",
  "Jeli\u0107",
  "Jemri\u0107",
  "Jerkovi\u0107",
  "Jonji\u0107",
  "Josipovi\u0107",
  "Jovanovac",
  "Jovanovi\u0107",
  "Jovi\u0107",
  "Jozi\u0107",
  "Jugovac",
  "Juki\u0107",
  "Jureti\u0107",
  "Jure\u0161ko",
  "Juri\u0107",
  "Juri\u0161i\u0107",
  "Jurjevi\u0107",
  "Jurkovi\u0107",
  "Jurlina",
  "Jur\u010di\u0107",
  "Kadija",
  "Kahlina",
  "Kalanjo\u0161",
  "Kalazi\u0107",
  "Kani\u0161ki",
  "Karagi\u0107",
  "Karamarko",
  "Karlovi\u0107",
  "Karmeli\u0107",
  "Karuza",
  "Kati\u0107",
  "Kauzlari\u0107",
  "Kelekovi\u0107",
  "Kele\u010di\u0107",
  "Keli\u0107",
  "Kerekovi\u0107",
  "Kevo",
  "Kinkela",
  "Kirin\u010di\u0107",
  "Klanac",
  "Klarin",
  "Klari\u0107",
  "Klasi\u0107",
  "Kligl",
  "Knezovi\u0107",
  "Kne\u017eevi\u0107",
  "Kocijan\u010di\u0107",
  "Kokanovi\u0107",
  "Kokori\u0107",
  "Kolarec",
  "Kolega",
  "Koli\u0107",
  "Komar",
  "Komljenovi\u0107",
  "Kopjar",
  "Kos",
  "Kosanovi\u0107",
  "Kosi\u0107",
  "Kostani\u0107",
  "Kostelac",
  "Kova\u010d",
  "Kova\u010dek",
  "Kova\u010devi\u0107",
  "Kova\u010di\u0107",
  "Ko\u0161ki",
  "Ko\u0161\u010devi\u0107",
  "Krajcar",
  "Kralj",
  "Kraljevi\u0107",
  "Kralji\u0107",
  "Kramari\u0107",
  "Kresonja",
  "Kri\u017ean",
  "Krpan",
  "Krznari\u0107",
  "Kr\u010deli\u0107",
  "Kr\u0161anac",
  "Kr\u017eelj",
  "Kujund\u017ei\u0107",
  "Kuku\u010dka",
  "Kunac",
  "Kupsjak",
  "Kurtoi\u0107",
  "Kuve\u017edi\u0107",
  "Kuzmi\u0107",
  "Ku\u010di\u0107",
  "Ku\u0161\u010devi\u0107",
  "Laba\u0161",
  "Labinjan",
  "Ladavac",
  "Lako\u0161eljac",
  "Lasi\u0107",
  "Lazar",
  "Legovi\u0107",
  "Lelas",
  "Leni\u0107",
  "Le\u0161i\u0107",
  "Le\u0161kovi\u0107",
  "Le\u0161\u010di\u0107",
  "Liber",
  "Licul",
  "Liovi\u0107",
  "Lisica",
  "Ljubeti\u0107",
  "Ljubi\u0107",
  "Ljubi\u010di\u0107",
  "Lojen",
  "Lorencin",
  "Lovri\u0107",
  "Luci\u0107",
  "Lukini\u0107",
  "Luki\u0107",
  "Luk\u0161a",
  "Luk\u0161i\u0107",
  "Lu\u010di\u0107",
  "Macan",
  "Maduni\u0107",
  "Magi\u0107",
  "Mahnet",
  "Majdeni\u0107",
  "Majstorovi\u0107",
  "Makovac",
  "Maleti\u0107",
  "Malnar",
  "Malo\u010da",
  "Mami\u0107",
  "Mamula",
  "Maras",
  "Marasovi\u0107",
  "Mara\u0161",
  "Marde\u0161i\u0107",
  "Mareti\u0107",
  "Marijanovi\u0107",
  "Marin",
  "Marinkovi\u0107",
  "Marinovi\u0107",
  "Mari\u0107",
  "Mari\u010devi\u0107",
  "Marjanovi\u0107",
  "Markanjevi\u0107",
  "Markovac",
  "Markovi\u0107",
  "Marku\u0161",
  "Martini\u0107",
  "Martinovi\u0107",
  "Martin\u010devi\u0107",
  "Marti\u0107",
  "Maru\u0161i\u0107",
  "Mar\u0161i\u0107",
  "Mar\u017ei\u0107",
  "Matahlija",
  "Matana",
  "Matas",
  "Mate\u0161a",
  "Matija\u0161",
  "Matijevi\u0107",
  "Mati\u0107",
  "Matko",
  "Matkovi\u0107",
  "Matokanovi\u0107",
  "Matovina",
  "Mato\u0161evi\u0107",
  "Matulin",
  "Matuli\u0107",
  "Mavra",
  "Ma\u0107e\u0161i\u0107",
  "Meda\u010d",
  "Medi\u0107",
  "Medved",
  "Mei\u0107",
  "Merka\u0161",
  "Mesari\u0107",
  "Mesi\u0107",
  "Mihali\u0107",
  "Mihaljevi\u0107",
  "Mihel\u010di\u0107",
  "Mihi\u0107",
  "Miki\u0107",
  "Mikle\u010di\u0107",
  "Mikulandra",
  "Mikulec",
  "Mikul\u010di\u0107",
  "Milas",
  "Milati\u0107",
  "Mileti\u0107",
  "Milevoj",
  "Milina",
  "Mili\u010di\u0107",
  "Miloslavi\u0107",
  "Miloti\u0107",
  "Milovac",
  "Mimica",
  "Mio\u010di\u0107",
  "Mirosavljevi\u0107",
  "Mirt",
  "Mi\u010deti\u0107",
  "Mi\u0161ak",
  "Mi\u0161e",
  "Mi\u0161kovi\u0107",
  "Modri\u0107",
  "Mofardin",
  "Mori\u0107",
  "Moscarda",
  "Moslavac",
  "Mo\u010dibob",
  "Mraovi\u0107",
  "Mudri",
  "Mudronja",
  "Mustapi\u0107",
  "Musta\u010d",
  "Mu\u0161\u0107et",
  "Mu\u017eina",
  "Mu\u017ei\u0107",
  "Naki\u0107",
  "Na\u010dinovi\u0107",
  "Nedi\u0107",
  "Nikoli\u0107",
  "Nimac",
  "Ni\u0161evi\u0107",
  "Ni\u017eeti\u0107",
  "Norac",
  "Novak",
  "Novosel",
  "Obradovi\u0107",
  "Obratov",
  "Odoba\u0161i\u0107",
  "Orbani\u0107",
  "Ore\u0161kovi\u0107",
  "Orli\u0107",
  "Orlovi\u0107",
  "Or\u0161oli\u0107",
  "Or\u0161o\u0161",
  "Or\u0161uli\u0107",
  "Ozimec",
  "Pajur",
  "Pali\u0107",
  "Pami\u0107",
  "Panduri\u0107",
  "Papak",
  "Papari\u0107",
  "Paradi",
  "Paveli\u0107",
  "Pavin",
  "Pavi\u0107",
  "Pavi\u010di\u0107",
  "Pavkovi\u0107",
  "Pavlovi\u0107",
  "Pecoti\u0107",
  "Pedi\u0161i\u0107",
  "Peharda",
  "Peni\u0107",
  "Perak",
  "Peri\u0107",
  "Peri\u0161i\u0107",
  "Perkov",
  "Perkovi\u0107",
  "Pero\u0161",
  "Peru\u0161ko",
  "Per\u010di\u0107",
  "Petek",
  "Peterlik",
  "Petri\u0107",
  "Petri\u010devi\u0107",
  "Petrovi\u0107",
  "Pe\u010dur",
  "Pe\u0161a",
  "Pe\u0161i\u0107",
  "Pikec",
  "Piljek",
  "Pintari\u0107",
  "Plantak",
  "Plantek",
  "Pla\u017eanin",
  "Ple\u0161e",
  "Pokas",
  "Pokos",
  "Poli\u0107",
  "Poljak",
  "Polonijo",
  "Polovi\u0107",
  "Pongrac",
  "Popovi\u0107",
  "Poropat",
  "Poslon",
  "Pozder",
  "Po\u017eega",
  "Predovan",
  "Prelec",
  "Preo\u010danin",
  "Pribani\u0107",
  "Priselac",
  "Prpi\u0107",
  "Prskalo",
  "Prtenja\u010da",
  "Puhari\u0107",
  "Puljiz",
  "Putinja",
  "Pu\u0161kari\u0107",
  "Radeli\u0107",
  "Radin",
  "Radinovi\u0107",
  "Radi\u0107",
  "Radman",
  "Radojkovi\u0107",
  "Radolovi\u0107",
  "Radovi\u0107",
  "Rado\u010daj",
  "Rado\u0161evi\u0107",
  "Ragu\u017e",
  "Rahija",
  "Rajn",
  "Raj\u010di\u0107",
  "Rakela",
  "Rakulji\u0107",
  "Raljevi\u0107",
  "Raspor",
  "Rastija",
  "Ra\u0111enovi\u0107",
  "Ra\u0161eta",
  "Ra\u0161i\u0107",
  "Ra\u017eov",
  "Rebi\u0107",
  "Renduli\u0107",
  "Resanovi\u0107",
  "Ribari\u0107",
  "Ribi\u0107",
  "Ribi\u010di\u0107",
  "Rijetkovi\u0107",
  "Risek",
  "Rito\u0161a",
  "Ri\u010dko",
  "Roca",
  "Roce",
  "Rogo\u0161i\u0107",
  "Rojni\u0107",
  "Roso",
  "Rube\u0161a",
  "Rubini\u0107",
  "Rukavina",
  "Rumora",
  "Sabljak",
  "Sabol",
  "Saka\u010d",
  "Salopek",
  "Sardeli\u0107",
  "Sedlar",
  "Semialjac",
  "Seni\u010di\u0107",
  "Ser\u0161i\u0107",
  "Sever",
  "Sikiri\u0107",
  "Simi\u0107",
  "Sino\u017ei\u0107",
  "Siroti\u0107",
  "Skupnjak",
  "Sladonja",
  "Slavica",
  "Smokovi\u0107",
  "Smoli\u0107",
  "Sobota",
  "Soka\u010d",
  "Soki\u0107",
  "Sokol",
  "Soldo",
  "Solomun",
  "Sori\u0107",
  "So\u0161i\u0107",
  "Sr\u0161en",
  "Stani\u0107",
  "Stani\u010di\u0107",
  "Stan\u010din",
  "Star\u010devi\u0107",
  "Stipanovi\u0107",
  "Stiperski",
  "Stojanov",
  "Stojni\u0107",
  "Stoj\u010devi\u0107",
  "Stolnik",
  "Sto\u0161i\u0107",
  "Stra\u017ei\u010di\u0107",
  "Strinavi\u0107",
  "Stupalo",
  "Sura\u0107",
  "Svetli\u010di\u0107",
  "Tepe\u0161",
  "Terlevi\u0107",
  "Terzi\u0107",
  "Te\u0161ija",
  "Tisaj",
  "Toi\u0107",
  "Tolj",
  "Tomi\u0107",
  "Tomi\u010di\u0107",
  "Tomljanovi\u0107",
  "Tonc",
  "Topi\u0107",
  "Toti\u0107",
  "Trbovi\u0107",
  "Trgov\u010di\u0107",
  "Triplat",
  "Trnski",
  "Trutani\u0107",
  "Tudi\u0107",
  "Tudor",
  "Tuksar",
  "Turina",
  "Turk",
  "Turudi\u0107",
  "Tur\u010dinov",
  "Tu\u0111a",
  "Tu\u0161ek",
  "Tu\u0161kan",
  "Ugrini\u0107",
  "Uki\u0107",
  "Urli\u0107",
  "U\u0161i\u0107",
  "Vaci",
  "Valenti\u0107",
  "Valjeti\u0107",
  "Varga",
  "Vei\u0107",
  "Vela",
  "Vidakovi\u0107",
  "Vidas",
  "Vidov",
  "Vidovi\u0107",
  "Viljevac",
  "Vinceti\u0107",
  "Vitasovi\u0107",
  "Vi\u017eintin",
  "Vladislavi\u0107",
  "Vla\u0161i\u0107",
  "Vojkovi\u0107",
  "Volarevi\u0107",
  "Volari\u0107",
  "Vorkapi\u0107",
  "Vozila",
  "Vrabelj",
  "Vrani\u0107",
  "Vrban",
  "Vretenar",
  "Vrhovec",
  "Vugdelija",
  "Vugec",
  "Vuk",
  "Vukman",
  "Vukobratovi\u0107",
  "Vukovi\u0107",
  "Vuku\u0161i\u0107",
  "Vuljak",
  "Vu\u010deti\u0107",
  "Vu\u010din",
  "Vu\u010dkovi\u0107",
  "Zakinja",
  "Zano\u0161ki",
  "Zeba",
  "Zebec",
  "Zeli\u0107",
  "Zgorelec",
  "Zmai\u0107",
  "Zrili\u0107",
  "Zrinski",
  "Zub\u010di\u0107",
  "\u0106ori\u0107",
  "\u0106osi\u0107",
  "\u0106uri\u0107",
  "\u010cagalj",
  "\u010cargonja",
  "\u010cizmi\u0107",
  "\u010ci\u0161",
  "\u010ci\u017eme\u0161ija",
  "\u010cop",
  "\u010coti\u0107",
  "\u010covi\u0107",
  "\u010cubri\u0107",
  "\u010cudi\u0107",
  "\u010cukman",
  "\u010culina",
  "\u010culjak",
  "\u010cupi\u0107",
  "\u010cu\u010dek",
  "\u0110ura\u0161evi\u0107",
  "\u0110urini\u0107",
  "\u0160ali\u0107",
  "\u0160anti\u0107",
  "\u0160arga\u010d",
  "\u0160ari\u0107",
  "\u0160arlija",
  "\u0160egovi\u0107",
  "\u0160elendi\u0107",
  "\u0160eparovi\u0107",
  "\u0160estak",
  "\u0160estan",
  "\u0160ibali\u0107",
  "\u0160imara",
  "\u0160imi\u0107",
  "\u0160imi\u010di\u0107",
  "\u0160imuni\u0107",
  "\u0160imunovi\u0107",
  "\u0160inkovi\u0107",
  "\u0160ipek",
  "\u0160ipi\u0107",
  "\u0160itum",
  "\u0160kara",
  "\u0160koda",
  "\u0160krlin",
  "\u0160krni\u010dki",
  "\u0160krti\u0107",
  "\u0160kugor",
  "\u0160kunca",
  "\u0160ok\u010devi\u0107",
  "\u0160o\u0161i\u0107",
  "\u0160o\u0161tari\u0107",
  "\u0160pika",
  "\u0160pi\u0161i\u0107",
  "\u0160poljari\u0107",
  "\u0160pralja",
  "\u0160tefanec",
  "\u0160tefovi\u0107",
  "\u0160tifani\u0107",
  "\u0160timac",
  "\u0160trbac",
  "\u0160trlji\u0107",
  "\u0160turlan",
  "\u0160unji\u0107",
  "\u0160upraha",
  "\u0160uran",
  "\u0160urbek",
  "\u0160urina",
  "\u0160verko",
  "\u017dabja\u010dan",
  "\u017dagar",
  "\u017derjav",
  "\u017de\u017eeli\u0107",
  "\u017dic",
  "\u017dikovi\u0107",
  "\u017divi\u0107",
  "\u017divkovi\u0107",
  "\u017dufika",
  "\u017dugec",
  "\u017dunec",
  "\u017dupani\u0107",
  "\u017duvela",
  "\u017du\u017ei\u0107"
)


person_hr_hr <- list(
  first_names = person_first_names_hr_hr,
  first_name_male = person_first_names_male_hr_hr,
  first_name_female = person_first_names_female_hr_hr,
  last_names = person_last_names_hr_hr
)
#' @title Person Provider for Croatian (Croatia)
#' @inherit PersonProvider description details return
#' @export
#' @family hr
#' @family HR
#' @details Note for female and male components that we fall back on generic
#' versions if the locale
#' doesn't provide a male/female version.
#' e.g., if no female first name we use first
#' name
#' @examples
#' x <- PersonProvider_hr_HR$new()
#' x$locale
#' x$render()
#' x$first_name()
#' x$first_name_female()
#' x$first_name_male()
#' x$last_name()
#' x$last_name_female()
#' x$last_name_male()
PersonProvider_hr_HR <- R6::R6Class(
  "PersonProvider_hr_HR",
  inherit = PersonProvider,
  private = list(

    # person name formats
    formats = person_formats_hr_hr,
    # person name data
    persons = person_hr_hr,
    locale_ = "hr_HR"
  )
)
